@@ -32,7 +32,7 @@ class AnafiPiloting:
 		initiates drone takeoff
 	land(queue)
 		initiates drone landing
-	wait_until_state(state, timeout)
+	wait_until_state(state_type, state, timeout)
 		wait until state is reached
 	move_by(x, y, z, angle, wait, queue)
 		moves the drone a given number of meters or rotates it to a set angle
@@ -93,27 +93,42 @@ class AnafiPiloting:
 		else:
 			self.add_action("Landing()")
 	
-	def wait_until_state(self, state, timeout = None):
+	def wait_until_state(self, state_type, state, timeout = None):
 		'''
 		Sends a wait until given {state : str} instruction to the {action_queue : str[]}
 		
 		Parameters
 		----------
+		state_type : str
+			the type of state to be waited for:
+			- move_by
+			- move_to
 		state : str
 			the state to be waited for:
+			move_by:
 			- "landed"
 			- "takingoff"
 			- "landing"
 			- "hovering"
 			- "flying"
+			move_to
+			- "done"
+			- "running"
+			- "cancelled"
 		timeout : int
 			the time in seconds to wait for state
 		'''
 	
 		if timeout == None:
-			self.add_action("FlyingStateChanged('{}')".format(state))
+			if state_type == "move_by":
+				self.add_action("FlyingStateChanged('{}')".format(state))
+			else:
+				self.add_action("moveToChanged(status='{}')".format(state))
 		else:
-			self.add_action("FlyingStateChanged('{}', _timeout={})".format(state, timeout))
+			if state_type == "move_by":
+				self.add_action("FlyingStateChanged('{}', _timeout={})".format(state, timeout))
+			else:
+				self.add_action("moveToChanged(status='{}', _timeout={})".format(state, timeout))
 		# print("------WAITING : {}------".format(state))
 	
 	def move_by(self, x, y, z, angle, wait = False, queue = False):
@@ -150,7 +165,7 @@ class AnafiPiloting:
 		else:
 			self.add_action("moveBy({}, {}, {}, {})".format(x, y, z, angle))
 			if wait == True:
-				self.wait_until_state("hovering")		
+				self.wait_until_state("move_by", "hovering")		
 	
 	def move_to(self, lat, lon, alt, orientation_mode = "NONE", heading = 0, wait = False, queue = False):
 		'''
@@ -184,7 +199,7 @@ class AnafiPiloting:
 			if wait == True:
 				assert self.drone(
 					moveTo(latitude=lat,longitude=lon,altitude=alt,orientation_mode=orientation_mode,heading=heading)
-					>> FlyingStateChanged("hovering")
+					>> moveToChanged(status = "DONE")
 				).wait().success()
 			else:
 				self.drone(
@@ -200,7 +215,7 @@ class AnafiPiloting:
 				lat,lon,alt,orientation_mode,heading
 			))
 			if wait == True:
-				self.wait_until_state("hovering")
+				self.wait_until_state("move_to", "hovering")
 		
 	def cancel_move_by(self):
 		'''
